pub struct RequestInfo {
pub id: String,
pub description: String,
pub status: RequestStatus,
}Expand description
One request, enough to identify, describe, and show the state of — what
dove requests lists and dove requests get looks up.
Fields
id: Stringdescription: Stringstatus: RequestStatusTrait Implementations
Sourceimpl Clone for RequestInfo
impl Clone for RequestInfo
Sourcefn clone(&self) -> RequestInfo
fn clone(&self) -> RequestInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RequestInfo
impl RefUnwindSafe for RequestInfo
impl Send for RequestInfo
impl Sync for RequestInfo
impl Unpin for RequestInfo
impl UnsafeUnpin for RequestInfo
impl UnwindSafe for RequestInfo